summaryrefslogtreecommitdiffstats
path: root/kivio/kiviopart/kiviosdk/kivio_shape.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
commitc9cb4f487428aad5d8cda5e3a4b9ad87390d7e54 (patch)
tree1ee1912ac4bb966475f0db0f2a78678661b4b4a5 /kivio/kiviopart/kiviosdk/kivio_shape.h
parent94844816550ad672ccfcdc25659c625546239998 (diff)
downloadkoffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.tar.gz
koffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 94844816550ad672ccfcdc25659c625546239998.
Diffstat (limited to 'kivio/kiviopart/kiviosdk/kivio_shape.h')
-rw-r--r--kivio/kiviopart/kiviosdk/kivio_shape.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kivio/kiviopart/kiviosdk/kivio_shape.h b/kivio/kiviopart/kiviosdk/kivio_shape.h
index 42adfed6..c83607d7 100644
--- a/kivio/kiviopart/kiviosdk/kivio_shape.h
+++ b/kivio/kiviopart/kiviosdk/kivio_shape.h
@@ -26,7 +26,7 @@
class KivioShape
{
protected:
- KivioShapeData m_shapeData; // The data inside this shape
+ KivioShapeData m_tqshapeData; // The data inside this tqshape
public:
KivioShape();
@@ -39,9 +39,9 @@ public:
bool loadXML( const TQDomElement & );
TQDomElement saveXML( TQDomDocument & );
- KivioShapeData::KivioShapeType shapeType() { return m_shapeData.shapeType(); }
+ KivioShapeData::KivioShapeType tqshapeType() { return m_tqshapeData.tqshapeType(); }
- KivioShapeData *shapeData() { return &m_shapeData; }
+ KivioShapeData *tqshapeData() { return &m_tqshapeData; }
static KivioShape *loadShapeArc( const TQDomElement & );
static KivioShape *loadShapeClosedPath( const TQDomElement & );